pub struct SecureEmulationRuntime { /* private fields */ }Expand description
Secure emulation runtime that uses sandboxing for safety
Implementations
Sourceimpl SecureEmulationRuntime
impl SecureEmulationRuntime
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new secure emulation runtime with default workflow-friendly configuration
Sourcepub fn new_with_config(config: SandboxConfig) -> Result<Self, ContainerError>
pub fn new_with_config(config: SandboxConfig) -> Result<Self, ContainerError>
Create a new secure emulation runtime with custom sandbox configuration